/*
 * Copyright (C) 2009, Jonas Fonseca <fonseca@diku.dk>
 * Copyright (C) 2007, Robin Rosenberg <robin.rosenberg@dewire.com>
 * Copyright (C) 2006-2007, Shawn O. Pearce <spearce@spearce.org>
 * and other copyright owners as documented in the project's IP log.
 *
 * This program and the accompanying materials are made available
 * under the terms of the Eclipse Distribution License v1.0 which
 * accompanies this distribution, is reproduced below, and is
 * available at http://www.eclipse.org/org/documents/edl-v10.php
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or
 * without modification, are permitted provided that the following
 * conditions are met:
 *
 * - Redistributions of source code must retain the above copyright
 *   notice, this list of conditions and the following disclaimer.
 *
 * - Redistributions in binary form must reproduce the above
 *   copyright notice, this list of conditions and the following
 *   disclaimer in the documentation and/or other materials provided
 *   with the distribution.
 *
 * - Neither the name of the Eclipse Foundation, Inc. nor the
 *   names of its contributors may be used to endorse or promote
 *   products derived from this software without specific prior
 *   written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
 * CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package org.eclipse.jgit.lib;

import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.text.MessageFormat;

import org.eclipse.jgit.JGitText;
import org.eclipse.jgit.errors.GitlinksNotSupportedException;
import org.eclipse.jgit.errors.SymlinksNotSupportedException;

/**
 * A tree visitor for writing a directory tree to the git object database. Blob
 * data is fetched from the files, not the cached blobs.
 *
 * @deprecated Use {@link org.eclipse.jgit.dircache.DirCache} instead.
 */
@Deprecated
public class WriteTree extends TreeVisitorWithCurrentDirectory {
	private final ObjectInserter inserter;

	/**
	 * Construct a WriteTree for a given directory
	 *
	 * @param sourceDirectory
	 * @param db
	 */
	public WriteTree(final File sourceDirectory, final Repository db) {
		super(sourceDirectory);
		inserter = db.newObjectInserter();
	}

	public void visitFile(final FileTreeEntry f) throws IOException {
		File path = new File(getCurrentDirectory(), f.getName());
		FileInputStream in = new FileInputStream(path);
		try {
			long sz = in.getChannel().size();
			f.setId(inserter.insert(Constants.OBJ_BLOB, sz, in));
			inserter.flush();
		} finally {
			inserter.release();
			in.close();
		}
	}

	public void visitSymlink(final SymlinkTreeEntry s) throws IOException {
		if (s.isModified()) {
			throw new SymlinksNotSupportedException(MessageFormat.format(
					JGitText.get().symlinkCannotBeWrittenAsTheLinkTarget, s.getFullName()));
		}
	}

	public void endVisitTree(final Tree t) throws IOException {
		super.endVisitTree(t);
		try {
			t.setId(inserter.insert(Constants.OBJ_TREE, t.format()));
			inserter.flush();
		} finally {
			inserter.release();
		}
	}

	public void visitGitlink(GitlinkTreeEntry s) throws IOException {
		if (s.isModified()) {
			throw new GitlinksNotSupportedException(s.getFullName());
		}
	}
}
